@@ -16,7 +16,6 @@
 
 #include <QFile>
 #include <QRegExp>
-#include <QStandardPaths>
 #include <QTextCodec>
 #include <QTextStream>
 
@@ -24,6 +23,7 @@
 #include <KTextEditor/Document>
 
 #include "kiledebug.h"
+#include "utilities.h"
 
 QMap<QString, ConvertMap*> ConvertMap::g_maps;
 
@@ -59,11 +59,11 @@ QString ConvertMap::encodingNameFor(const QString & name)
 
     std = std.toLower();
 
-    if(std.startsWith("iso8859-")) {
+    if(std.startsWith(QLatin1String("iso8859-"))) {
         return "latin" + std.right(1);
     }
 
-    if(std.startsWith("cp")) {
+    if(std.startsWith(QLatin1String("cp"))) {
         return "cp" + std.right(4);
     }
 
@@ -81,11 +81,11 @@ QString ConvertMap::isoNameFor(const QString & name)
 
     std = std.toLower();
 
-    if(std.startsWith("latin")) {
+    if(std.startsWith(QLatin1String("latin"))) {
         return "ISO 8859-" + std.right(1);
     }
 
-    if(std.startsWith("cp")) {
+    if(std.startsWith(QLatin1String("cp"))) {
         return "cp " + std.right(4);
     }
 
@@ -118,7 +118,7 @@ bool ConvertMap::load()
     //makeMap(encoding());
 
     //if map already exists, replace it
-    QFile qf(QStandardPaths::locate(QStandardPaths::DataLocation, "encodings/" + encoding() + ".enc"));
+    QFile qf(KileUtilities::locate(QStandardPaths::AppDataLocation, "encodings/" + encoding() + ".enc"));
 
     if(qf.open(QIODevice::ReadOnly)) {
         QTextStream stream(&qf);
