@@ -28,17 +28,17 @@ namespace KileDialog {
 
 class TabularCellDelegate : public QStyledItemDelegate {
 public:
-    TabularCellDelegate(QTableWidget *parent = 0);
+    explicit TabularCellDelegate(QTableWidget *parent = 0);
 
-    virtual void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const;
+    virtual void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
     virtual QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option,
-                                  const QModelIndex &index) const;
-    virtual void setEditorData(QWidget *editor, const QModelIndex &index) const;
+                                  const QModelIndex &index) const override;
+    virtual void setEditorData(QWidget *editor, const QModelIndex &index) const override;
     virtual void setModelData(QWidget *editor, QAbstractItemModel *model,
-                              const QModelIndex &index) const;
+                              const QModelIndex &index) const override;
     virtual void updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option,
-                                      const QModelIndex &index) const;
+                                      const QModelIndex &index) const override;
 
 private:
     QTableWidget *m_Table;
